pub fn create_engine() -> EngineExpand description
Creates and configures a new Rhai engine with all necessary modules and functions.
pub fn create_engine() -> EngineCreates and configures a new Rhai engine with all necessary modules and functions.